# Before `make install' is performed this script should be runnable with
# `make test'. After `make install' it should work as `perl test.pl'

######################### We start with some black magic to print on failure.

# Change 1..1 below to 1..last_test_to_print .
# (It may become useful if the test is moved to ./t subdirectory.)

BEGIN { $| = 1; }
END {print "not ok 1\n" unless $loaded;}
use Lingua::EN::Nickname;
$loaded = 1;

######################### End of black magic.

# Insert your test code below (better if it prints "ok 13"
# (correspondingly "not ok 13") depending on the success of chunk 13
# of the test code):

use Test;
BEGIN { plan tests => 17 }

ok(nickname_eq(split)) while(<DATA>);
ok(!nickname_eq(qw(Lisa Bart)));


__END__
Liz     Beth
Peggy   Margaret
Charlie Chuck
Brian   Ryan
Ada     Adaline
Peg     Midge
Lizzy   Lise
Lig     Elijah
Allie   Alice
Ali     Alice
Mari    Mary
Mary    Anna
Mary    Maryanne
Becky   Rebecca
Ricky   Richard
Vicky   Victoria
